Simple tests
------------

Ensure your device works with these simple tests.

.. literalinclude:: ../examples/lsm303_accel_simpletest.py
    :caption: examples/lsm303_simpletest.py
    :linenos:

Fast Acceleration Example
-------------------------

Example to demonstrate fast acceleration data acquisition

.. literalinclude:: ../examples/lsm303_accel_fast.py
    :caption: examples/lsm303_fast_accel.py
    :linenos:


Inclinometer Example
-------------------------

Demonstrate inclinometer example

.. literalinclude:: ../examples/lsm303_accel_inclinometer.py
    :caption: examples/lsm303_accel_inclinometer.py
    :linenos:


Tap Detection Example
-------------------------

Tap detection example

.. literalinclude:: ../examples/lsm303_accel_tap_detection.py
    :caption: examples/lsm303_accel_tap_detection.py
    :linenos:
